@@ -36,7 +36,6 @@ from tests import create_session, mock, temporary_file, unittest
 # which should be prefered. When backwards compatibility can be dropped then
 # this test should be removed.
 class BaseSessionTest(unittest.TestCase):
-
     def setUp(self):
         self.env_vars = {
             'profile': (None, 'FOO_PROFILE', None, None),
@@ -45,7 +44,7 @@ class BaseSessionTest(unittest.TestCase):
             'config_file': (None, 'FOO_CONFIG_FILE', None, None),
             'credentials_file': (None, None, '/tmp/nowhere', None),
             'ca_bundle': ('foo_ca_bundle', 'FOO_AWS_CA_BUNDLE', None, None),
-            'api_versions': ('foo_api_versions', None, {}, None)
+            'api_versions': ('foo_api_versions', None, {}, None),
         }
         self.environ = {}
         self.environ_patch = mock.patch('os.environ', self.environ)
@@ -54,8 +53,9 @@ class BaseSessionTest(unittest.TestCase):
         self.environ['FOO_REGION'] = 'us-west-11'
         data_path = os.path.join(os.path.dirname(__file__), 'data')
         self.environ['FOO_DATA_PATH'] = data_path
-        config_path = os.path.join(os.path.dirname(__file__), 'cfg',
-                                   'foo_config')
+        config_path = os.path.join(
+            os.path.dirname(__file__), 'cfg', 'foo_config'
+        )
         self.environ['FOO_CONFIG_FILE'] = config_path
         self.session = create_session(session_vars=self.env_vars)
 
@@ -64,7 +64,6 @@ class BaseSessionTest(unittest.TestCase):
 
 
 class SessionTest(BaseSessionTest):
-
     def close_log_file_handler(self, tempdir, filename):
         logger = logging.getLogger('botocore')
         handlers = logger.handlers
@@ -82,8 +81,12 @@ class SessionTest(BaseSessionTest):
 
     def test_supports_multiple_env_vars_for_single_logical_name(self):
         env_vars = {
-            'profile': (None, ['BAR_DEFAULT_PROFILE', 'BAR_PROFILE'],
-                        None, None),
+            'profile': (
+                None,
+                ['BAR_DEFAULT_PROFILE', 'BAR_PROFILE'],
+                None,
+                None,
+            ),
         }
         session = create_session(session_vars=env_vars)
         self.environ['BAR_DEFAULT_PROFILE'] = 'first'
@@ -102,8 +105,12 @@ class SessionTest(BaseSessionTest):
 
     def test_multiple_env_vars_uses_second_var(self):
         env_vars = {
-            'profile': (None, ['BAR_DEFAULT_PROFILE', 'BAR_PROFILE'],
-                        None, None),
+            'profile': (
+                None,
+                ['BAR_DEFAULT_PROFILE', 'BAR_PROFILE'],
+                None,
+                None,
+            ),
         }
         session = create_session(session_vars=env_vars)
         self.environ.pop('BAR_DEFAULT_PROFILE', None)
@@ -112,8 +119,9 @@ class SessionTest(BaseSessionTest):
 
     def test_profile(self):
         self.assertEqual(self.session.get_config_variable('profile'), 'foo')
-        self.assertEqual(self.session.get_config_variable('region'),
-                         'us-west-11')
+        self.assertEqual(
+            self.session.get_config_variable('region'), 'us-west-11'
+        )
         self.session.get_config_variable('profile') == 'default'
         saved_region = self.environ['FOO_REGION']
         del self.environ['FOO_REGION']
@@ -154,19 +162,25 @@ class SessionTest(BaseSessionTest):
         # FOO_TIMEOUT env var, with a conversion function
         # of int().
         self.env_vars['metadata_service_timeout'] = (
-            None, 'FOO_TIMEOUT', None, int)
+            None,
+            'FOO_TIMEOUT',
+            None,
+            int,
+        )
         # Environment variables are always strings.
         self.environ['FOO_TIMEOUT'] = '10'
         session = create_session(session_vars=self.env_vars)
         # But we should type convert this to a string.
         self.assertEqual(
-            session.get_config_variable('metadata_service_timeout'), 10)
+            session.get_config_variable('metadata_service_timeout'), 10
+        )
 
     def test_default_profile_specified_raises_exception(self):
         # If you explicity set the default profile and you don't
         # have that in your config file, an exception is raised.
-        config_path = os.path.join(os.path.dirname(__file__), 'cfg',
-                                   'boto_config_empty')
+        config_path = os.path.join(
+            os.path.dirname(__file__), 'cfg', 'boto_config_empty'
+        )
         self.environ['FOO_CONFIG_FILE'] = config_path
         self.environ['FOO_PROFILE'] = 'default'
         session = create_session(session_vars=self.env_vars)
@@ -201,9 +215,13 @@ class SessionTest(BaseSessionTest):
             f.flush()
 
             full_config = self.session.full_config
-            self.assertEqual(full_config['profiles']['newprofile'],
-                             {'aws_access_key_id': 'FROM_CREDS_FILE_1',
-                              'aws_secret_access_key': 'FROM_CREDS_FILE_2'})
+            self.assertEqual(
+                full_config['profiles']['newprofile'],
+                {
+                    'aws_access_key_id': 'FROM_CREDS_FILE_1',
+                    'aws_secret_access_key': 'FROM_CREDS_FILE_2',
+                },
+            )
 
     def test_path_not_in_available_profiles(self):
         with temporary_file('w') as f:
@@ -214,9 +232,7 @@ class SessionTest(BaseSessionTest):
             f.flush()
 
             profiles = self.session.available_profiles
-            self.assertEqual(
-                set(profiles),
-                set(['foo', 'default', 'newprofile']))
+            self.assertEqual(set(profiles), {'foo', 'default', 'newprofile'})
 
     def test_emit_delegates_to_emitter(self):
         calls = []
@@ -228,8 +244,9 @@ class SessionTest(BaseSessionTest):
 
     def test_emitter_can_be_passed_in(self):
         events = HierarchicalEmitter()
-        session = create_session(session_vars=self.env_vars,
-                                 event_hooks=events)
+        session = create_session(
+            session_vars=self.env_vars, event_hooks=events
+        )
         calls = []
         handler = lambda **kwargs: calls.append(kwargs)
         events.register('foo', handler)
@@ -278,33 +295,39 @@ class SessionTest(BaseSessionTest):
 
 class TestBuiltinEventHandlers(BaseSessionTest):
     def setUp(self):
-        super(TestBuiltinEventHandlers, self).setUp()
+        super().setUp()
         self.builtin_handlers = [
             ('foo', self.on_foo),
         ]
         self.foo_called = False
-        self.handler_patch = mock.patch('botocore.handlers.BUILTIN_HANDLERS',
-                                        self.builtin_handlers)
+        self.handler_patch = mock.patch(
+            'botocore.handlers.BUILTIN_HANDLERS', self.builtin_handlers
+        )
         self.handler_patch.start()
 
     def on_foo(self, **kwargs):
         self.foo_called = True
 
     def tearDown(self):
-        super(TestBuiltinEventHandlers, self).tearDown()
+        super().tearDown()
         self.handler_patch.stop()
 
     def test_registered_builtin_handlers(self):
-        session = botocore.session.Session(self.env_vars, None,
-                                           include_builtin_handlers=True)
+        session = botocore.session.Session(
+            self.env_vars, None, include_builtin_handlers=True
+        )
         session.emit('foo')
         self.assertTrue(self.foo_called)
 
 
 class TestSessionConfigurationVars(BaseSessionTest):
     def test_per_session_config_vars(self):
-        self.session.session_var_map['foobar'] = (None, 'FOOBAR',
-                                                  'default', None)
+        self.session.session_var_map['foobar'] = (
+            None,
+            'FOOBAR',
+            'default',
+            None,
+        )
         # Default value.
         self.assertEqual(self.session.get_config_variable('foobar'), 'default')
         # Retrieve from os environment variable.
@@ -313,54 +336,82 @@ class TestSessionConfigurationVars(BaseSessionTest):
 
         # Explicit override.
         self.session.set_config_variable('foobar', 'session-instance')
-        self.assertEqual(self.session.get_config_variable('foobar'),
-                         'session-instance')
+        self.assertEqual(
+            self.session.get_config_variable('foobar'), 'session-instance'
+        )
 
         # Can disable this check via the ``methods`` arg.
         del self.environ['FOOBAR']
-        self.assertEqual(self.session.get_config_variable(
-            'foobar', methods=('env', 'config')), 'default')
+        self.assertEqual(
+            self.session.get_config_variable(
+                'foobar', methods=('env', 'config')
+            ),
+            'default',
+        )
 
     def test_default_value_can_be_overriden(self):
-        self.session.session_var_map['foobar'] = (None, 'FOOBAR', 'default',
-                                                  None)
+        self.session.session_var_map['foobar'] = (
+            None,
+            'FOOBAR',
+            'default',
+            None,
+        )
         self.assertEqual(self.session.get_config_variable('foobar'), 'default')
 
     def test_can_get_session_vars_info_from_default_session(self):
         # This test is to ensure that you can still reach the session_vars_map
         # information from the session and that it has the expected value.
         self.session = create_session()
-        self.assertEqual(self.session.session_var_map['region'],
-                         ('region', 'AWS_DEFAULT_REGION', None, None))
+        self.assertEqual(
+            self.session.session_var_map['region'],
+            ('region', 'AWS_DEFAULT_REGION', None, None),
+        )
         self.assertEqual(
             self.session.session_var_map['profile'],
-            (None, ['AWS_DEFAULT_PROFILE', 'AWS_PROFILE'], None, None))
+            (None, ['AWS_DEFAULT_PROFILE', 'AWS_PROFILE'], None, None),
+        )
         self.assertEqual(
             self.session.session_var_map['data_path'],
-            ('data_path', 'AWS_DATA_PATH', None, None))
+            ('data_path', 'AWS_DATA_PATH', None, None),
+        )
         self.assertEqual(
             self.session.session_var_map['config_file'],
-            (None, 'AWS_CONFIG_FILE', '~/.aws/config', None))
+            (None, 'AWS_CONFIG_FILE', '~/.aws/config', None),
+        )
         self.assertEqual(
             self.session.session_var_map['ca_bundle'],
-            ('ca_bundle', 'AWS_CA_BUNDLE', None, None))
+            ('ca_bundle', 'AWS_CA_BUNDLE', None, None),
+        )
         self.assertEqual(
             self.session.session_var_map['api_versions'],
-            ('api_versions', None, {}, None))
+            ('api_versions', None, {}, None),
+        )
         self.assertEqual(
             self.session.session_var_map['credentials_file'],
-            (None, 'AWS_SHARED_CREDENTIALS_FILE', '~/.aws/credentials', None))
+            (None, 'AWS_SHARED_CREDENTIALS_FILE', '~/.aws/credentials', None),
+        )
         self.assertEqual(
             self.session.session_var_map['metadata_service_timeout'],
-            ('metadata_service_timeout',
-             'AWS_METADATA_SERVICE_TIMEOUT', 1, int))
+            (
+                'metadata_service_timeout',
+                'AWS_METADATA_SERVICE_TIMEOUT',
+                1,
+                int,
+            ),
+        )
         self.assertEqual(
             self.session.session_var_map['metadata_service_num_attempts'],
-            ('metadata_service_num_attempts',
-             'AWS_METADATA_SERVICE_NUM_ATTEMPTS', 1, int))
+            (
+                'metadata_service_num_attempts',
+                'AWS_METADATA_SERVICE_NUM_ATTEMPTS',
+                1,
+                int,
+            ),
+        )
         self.assertEqual(
             self.session.session_var_map['parameter_validation'],
-            ('parameter_validation', None, True, None))
+            ('parameter_validation', None, True, None),
+        )
 
 
 class TestSessionPartitionFiles(BaseSessionTest):
@@ -368,14 +419,16 @@ class TestSessionPartitionFiles(BaseSessionTest):
         mock_resolver = mock.Mock()
         mock_resolver.get_available_partitions.return_value = ['foo']
         self.session._register_internal_component(
-            'endpoint_resolver', mock_resolver)
+            'endpoint_resolver', mock_resolver
+        )
         self.assertEqual(['foo'], self.session.get_available_partitions())
 
     def test_proxies_list_endpoints_to_resolver(self):
         resolver = mock.Mock()
         resolver.get_available_endpoints.return_value = ['a', 'b']
         self.session._register_internal_component(
-            'endpoint_resolver', resolver)
+            'endpoint_resolver', resolver
+        )
         self.session.get_available_regions('foo', 'bar', True)
 
     def test_provides_empty_list_for_unknown_service_regions(self):
@@ -395,7 +448,8 @@ class TestSessionUserAgent(BaseSessionTest):
     def test_can_append_to_user_agent(self):
         self.session.user_agent_extra = 'custom-thing/other'
         self.assertTrue(
-            self.session.user_agent().endswith('custom-thing/other'))
+            self.session.user_agent().endswith('custom-thing/other')
+        )
 
     def test_execution_env_not_set(self):
         self.assertFalse(self.session.user_agent().endswith('FooEnv'))
@@ -414,8 +468,9 @@ class TestSessionUserAgent(BaseSessionTest):
 
 class TestConfigLoaderObject(BaseSessionTest):
     def test_config_loader_delegation(self):
-        session = create_session(session_vars=self.env_vars,
-                                 profile='credfile-profile')
+        session = create_session(
+            session_vars=self.env_vars, profile='credfile-profile'
+        )
         with temporary_file('w') as f:
             f.write('[credfile-profile]\naws_access_key_id=a\n')
             f.write('aws_secret_access_key=b\n')
@@ -423,9 +478,10 @@ class TestConfigLoaderObject(BaseSessionTest):
             session.set_config_variable('credentials_file', f.name)
             # Now trying to retrieve the scoped config should pull in
             # values from the shared credentials file.
-            self.assertEqual(session.get_scoped_config(),
-                             {'aws_access_key_id': 'a',
-                              'aws_secret_access_key': 'b'})
+            self.assertEqual(
+                session.get_scoped_config(),
+                {'aws_access_key_id': 'a', 'aws_secret_access_key': 'b'},
+            )
 
 
 class TestGetServiceModel(BaseSessionTest):
@@ -452,7 +508,8 @@ class TestGetPaginatorModel(BaseSessionTest):
         self.assertIsInstance(model, PaginatorModel)
         # Verify we called the loader correctly.
         loader.load_service_model.assert_called_with(
-            'foo', 'paginators-1', None)
+            'foo', 'paginators-1', None
+        )
 
 
 class TestGetWaiterModel(BaseSessionTest):
@@ -467,8 +524,7 @@ class TestGetWaiterModel(BaseSessionTest):
         self.assertIsInstance(model, WaiterModel)
         self.assertEqual(model.waiter_names, [])
         # and (2) call the loader correctly.
-        loader.load_service_model.assert_called_with(
-            'foo', 'waiters-2', None)
+        loader.load_service_model.assert_called_with('foo', 'waiters-2', None)
 
 
 class TestCreateClient(BaseSessionTest):
@@ -478,28 +534,33 @@ class TestCreateClient(BaseSessionTest):
 
     def test_credential_provider_not_called_when_creds_provided(self):
         cred_provider = mock.Mock()
-        self.session.register_component(
-            'credential_provider', cred_provider)
+        self.session.register_component('credential_provider', cred_provider)
         self.session.create_client(
-            'sts', 'us-west-2',
+            'sts',
+            'us-west-2',
             aws_access_key_id='foo',
             aws_secret_access_key='bar',
-            aws_session_token='baz')
-        self.assertFalse(cred_provider.load_credentials.called,
-                         "Credential provider was called even though "
-                         "explicit credentials were provided to the "
-                         "create_client call.")
+            aws_session_token='baz',
+        )
+        self.assertFalse(
+            cred_provider.load_credentials.called,
+            "Credential provider was called even though "
+            "explicit credentials were provided to the "
+            "create_client call.",
+        )
 
     def test_cred_provider_called_when_partial_creds_provided(self):
         with self.assertRaises(botocore.exceptions.PartialCredentialsError):
             self.session.create_client(
-                'sts', 'us-west-2',
+                'sts',
+                'us-west-2',
                 aws_access_key_id='foo',
-                aws_secret_access_key=None
+                aws_secret_access_key=None,
             )
         with self.assertRaises(botocore.exceptions.PartialCredentialsError):
             self.session.create_client(
-                'sts', 'us-west-2',
+                'sts',
+                'us-west-2',
                 aws_access_key_id=None,
                 aws_secret_access_key='foo',
             )
@@ -514,10 +575,16 @@ class TestCreateClient(BaseSessionTest):
         config = botocore.config.Config(region_name='us-west-2')
         self.session.create_client('sts', config=config)
         client_creator.return_value.create_client.assert_called_with(
-            service_name=mock.ANY, region_name=mock.ANY, is_secure=mock.ANY,
-            endpoint_url=mock.ANY, verify=mock.ANY, credentials=mock.ANY,
-            scoped_config=mock.ANY, client_config=config,
-            api_version=mock.ANY)
+            service_name=mock.ANY,
+            region_name=mock.ANY,
+            is_secure=mock.ANY,
+            endpoint_url=mock.ANY,
+            verify=mock.ANY,
+            credentials=mock.ANY,
+            scoped_config=mock.ANY,
+            client_config=config,
+            api_version=mock.ANY,
+        )
 
     @mock.patch('botocore.client.ClientCreator')
     def test_create_client_with_default_client_config(self, client_creator):
@@ -526,10 +593,16 @@ class TestCreateClient(BaseSessionTest):
         self.session.create_client('sts')
 
         client_creator.return_value.create_client.assert_called_with(
-            service_name=mock.ANY, region_name=mock.ANY, is_secure=mock.ANY,
-            endpoint_url=mock.ANY, verify=mock.ANY, credentials=mock.ANY,
-            scoped_config=mock.ANY, client_config=config,
-            api_version=mock.ANY)
+            service_name=mock.ANY,
+            region_name=mock.ANY,
+            is_secure=mock.ANY,
+            endpoint_url=mock.ANY,
+            verify=mock.ANY,
+            credentials=mock.ANY,
+            scoped_config=mock.ANY,
+            client_config=config,
+            api_version=mock.ANY,
+        )
 
     @mock.patch('botocore.client.ClientCreator')
     def test_create_client_with_merging_client_configs(self, client_creator):
@@ -541,7 +614,9 @@ class TestCreateClient(BaseSessionTest):
         # Grab the client config used in creating the client
         used_client_config = (
             client_creator.return_value.create_client.call_args[1][
-                'client_config'])
+                'client_config'
+            ]
+        )
         # Check that the client configs were merged
         self.assertEqual(used_client_config.region_name, 'us-east-1')
         # Make sure that the client config used is not the default client
@@ -550,15 +625,15 @@ class TestCreateClient(BaseSessionTest):
         self.assertIsNot(used_client_config, other_config)
 
     def test_create_client_with_region(self):
-        ec2_client = self.session.create_client(
-            'ec2', 'us-west-2')
+        ec2_client = self.session.create_client('ec2', 'us-west-2')
         self.assertEqual(ec2_client.meta.region_name, 'us-west-2')
 
     def test_create_client_with_region_and_client_config(self):
         config = botocore.config.Config()
         # Use a client config with no region configured.
         ec2_client = self.session.create_client(
-            'ec2', region_name='us-west-2', config=config)
+            'ec2', region_name='us-west-2', config=config
+        )
         self.assertEqual(ec2_client.meta.region_name, 'us-west-2')
 
         # If the region name is changed, it should not change the
@@ -567,8 +642,7 @@ class TestCreateClient(BaseSessionTest):
         self.assertEqual(ec2_client.meta.region_name, 'us-west-2')
 
         # Now make a new client with the updated client config.
-        ec2_client = self.session.create_client(
-            'ec2', config=config)
+        ec2_client = self.session.create_client('ec2', config=config)
         self.assertEqual(ec2_client.meta.region_name, 'us-east-1')
 
     def test_create_client_no_region_and_no_client_config(self):
@@ -586,8 +660,9 @@ class TestCreateClient(BaseSessionTest):
             f.flush()
 
             self.session.create_client('ec2', 'us-west-2')
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             self.assertEqual(call_kwargs['verify'], 'config-certs.pem')
 
     @mock.patch('botocore.client.ClientCreator')
@@ -600,7 +675,8 @@ class TestCreateClient(BaseSessionTest):
     @mock.patch('botocore.client.ClientCreator')
     def test_create_client_with_verify_param(self, client_creator):
         self.session.create_client(
-            'ec2', 'us-west-2', verify='verify-certs.pem')
+            'ec2', 'us-west-2', verify='verify-certs.pem'
+        )
         call_kwargs = client_creator.return_value.create_client.call_args[1]
         self.assertEqual(call_kwargs['verify'], 'verify-certs.pem')
 
@@ -620,9 +696,11 @@ class TestCreateClient(BaseSessionTest):
 
             # Set the ca cert using the verify parameter
             self.session.create_client(
-                'ec2', 'us-west-2', verify='verify-certs.pem')
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+                'ec2', 'us-west-2', verify='verify-certs.pem'
+            )
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             # The verify parameter should override all the other
             # configurations
             self.assertEqual(call_kwargs['verify'], 'verify-certs.pem')
@@ -641,13 +719,16 @@ class TestCreateClient(BaseSessionTest):
             self.environ['FOO_CONFIG_FILE'] = f.name
             self.session = create_session(session_vars=self.env_vars)
             f.write('[default]\n')
-            f.write('foo_api_versions =\n'
-                    '    myservice = %s\n' % config_api_version)
+            f.write(
+                'foo_api_versions =\n'
+                '    myservice = %s\n' % config_api_version
+            )
             f.flush()
 
             self.session.create_client('myservice', 'us-west-2')
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             self.assertEqual(call_kwargs['api_version'], config_api_version)
 
     @mock.patch('botocore.client.ClientCreator')
@@ -667,15 +748,18 @@ class TestCreateClient(BaseSessionTest):
             f.flush()
 
             self.session.create_client('myservice', 'us-west-2')
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             self.assertEqual(call_kwargs['api_version'], config_api_version)
 
             self.session.create_client('myservice2', 'us-west-2')
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             self.assertEqual(
-                call_kwargs['api_version'], second_config_api_version)
+                call_kwargs['api_version'], second_config_api_version
+            )
 
     @mock.patch('botocore.client.ClientCreator')
     def test_param_api_version_overrides_config_value(self, client_creator):
@@ -686,14 +770,18 @@ class TestCreateClient(BaseSessionTest):
             self.environ['FOO_CONFIG_FILE'] = f.name
             self.session = create_session(session_vars=self.env_vars)
             f.write('[default]\n')
-            f.write('foo_api_versions =\n'
-                    '    myservice = %s\n' % config_api_version)
+            f.write(
+                'foo_api_versions =\n'
+                '    myservice = %s\n' % config_api_version
+            )
             f.flush()
 
             self.session.create_client(
-                'myservice', 'us-west-2', api_version=override_api_version)
-            call_kwargs = client_creator.return_value.\
-                create_client.call_args[1]
+                'myservice', 'us-west-2', api_version=override_api_version
+            )
+            call_kwargs = client_creator.return_value.create_client.call_args[
+                1
+            ]
             self.assertEqual(call_kwargs['api_version'], override_api_version)
 
 
@@ -702,7 +790,8 @@ class TestSessionComponent(BaseSessionTest):
         component = object()
         self.session._register_internal_component('internal', component)
         self.assertIs(
-            self.session._get_internal_component('internal'), component)
+            self.session._get_internal_component('internal'), component
+        )
         with self.assertRaises(ValueError):
             # get_component has been deprecated to the public
             with pytest.warns(DeprecationWarning):
@@ -710,22 +799,24 @@ class TestSessionComponent(BaseSessionTest):
 
     def test_internal_endpoint_resolver_is_same_as_deprecated_public(self):
         endpoint_resolver = self.session._get_internal_component(
-            'endpoint_resolver')
+            'endpoint_resolver'
+        )
         # get_component has been deprecated to the public
         with pytest.warns(DeprecationWarning):
             self.assertIs(
                 self.session.get_component('endpoint_resolver'),
-                endpoint_resolver
+                endpoint_resolver,
             )
 
     def test_internal_exceptions_factory_is_same_as_deprecated_public(self):
         exceptions_factory = self.session._get_internal_component(
-            'exceptions_factory')
+            'exceptions_factory'
+        )
         # get_component has been deprecated to the public
         with pytest.warns(DeprecationWarning):
             self.assertIs(
                 self.session.get_component('exceptions_factory'),
-                exceptions_factory
+                exceptions_factory,
             )
 
 
@@ -771,7 +862,9 @@ class TestComponentLocator(unittest.TestCase):
         self.components.register_component('foo', second)
         self.assertIs(self.components.get_component('foo'), second)
 
-    def test_lazy_registration_factory_does_not_remove_from_list_on_error(self):
+    def test_lazy_registration_factory_does_not_remove_from_list_on_error(
+        self,
+    ):
         class ArbitraryError(Exception):
             pass
 
